from byubit import Bit


# This is one way of solving the blue ocean problem. It is probably the most
# difficult! It goes right to left, then left to right, ascending rows each time.
# Since we don't know how many rows there are, we might end up at the top left
# or the top right. So this makes getting back home difficult.

def color_blue(bit):
    """

    :param bit: a bit world
    :return: nothing

    Color a single row blue
    """
    bit.paint('blue')
    while bit.front_clear():
        bit.move()
        bit.paint("blue")


def turn_left(bit):
    """

    :param bit: a bit world
    :return: nothing

    Moves up to the next row and turns bit left
    """
    bit.left()
    bit.move()
    bit.left()


def turn_right(bit):
    """

    :param bit: a bit world
    :return: nothing

    Moves bit up to the next row and turns bit right
    """
    bit.right()
    bit.move()
    bit.right()


def return_to_beginning_from_top_left(bit):
    """

    :param bit: a bit world
    :return: nothing

    Moves bit back to the bottom left, starting from the top left
    """
    bit.left()
    while bit.front_clear():
        bit.move()
    bit.left()


def return_to_beginning_from_top_right(bit):
    """

    :param bit: a bit world
    :return: nothing

    Moves bit back to the bottom left, starting from the top right
    """
    bit.left()
    bit.left()
    while bit.front_clear():
        bit.move()
    bit.left()
    while bit.front_clear():
        bit.move()
    bit.left()


# This code does work with different sizes of grids! Try replacing 6, 6
# with 6, 7
@Bit.run_from_empty(6, 6)
def run(bit):
    while bit.front_clear():
        # make a blue row
        color_blue(bit)
        # go up to the next row if that is possible
        if bit.left_clear():
            turn_left(bit)
            # make another blue row (in the opposite direction)
            color_blue(bit)
            # go up to the next row if that is possible
            if bit.right_clear():
                turn_right(bit)

    # figure out if we ended up in the top left or top right corner
    if not bit.right_clear():
        return_to_beginning_from_top_left(bit)
    else:
        return_to_beginning_from_top_right(bit)
