from byubit import Bit


# This is a good way of solving the blue ocean problem. It fills one column
# at a time and goes back to the start of the column before moving to the
# next column. So all the painting is one direction. Painting in one direction
# makes the solution fairly easy to code because you don't have to worry about
# what direction you are facing each time you paint.

from byubit import Bit


def go(bit):
    """

    :param bit: a bit world
    :return: nothing

    Go until the end of the world
    """
    while bit.front_clear():
        bit.move()


def go_blue(bit):
    """

    :param bit: a bit world
    :return: nothing

    Go until the end of the world, painting blue as you go
    """
    bit.paint('blue')
    while bit.front_clear():
        bit.move()
        bit.paint('blue')


def turn_around(bit):
    """

    :param bit: a bit world
    :return: nothing

    Bit is facing one way. Turn it around to the other direction.
    """
    bit.left()
    bit.left()


def fill_column_with_blue(bit):
    """

    :param bit: a bit world
    :return: nothing

    Bit starts facing up
    Bit turns right and fills the row with blue
    Bit returns to the left and turns to face up
    """
    bit.left()
    go_blue(bit)
    turn_around(bit)
    go(bit)
    bit.left()


@Bit.run_from_empty(6, 6)
def run(bit):
    """

    :param bit: a bit world
    :return:

    Bit starts in the bottom left, facing right. Bit fills the entire
    world with blue.
    """
    # fill one column with blue
    fill_column_with_blue(bit)
    # keep going as long as there is another column to fill
    while bit.front_clear():
        # move to the next column
        bit.move()
        # fill that column with blue
        fill_column_with_blue(bit)

    # turn around and go back to the beginning
    turn_around(bit)
    go(bit)
    turn_around(bit)